==> iutest_c-1.2.0.zip: iutest_c-1.2.0/include/internal/iutest_params_util_c.h <==
/*======================================================================
----------------------------------------------------------------------*/
/**
 * @file		iutest_params_util_c.h
 * @brief		iris unit test parameter eXgp util t@C
 *
 * @author		t.sirayanagi
 * @version		1.0
 *
 * @par			copyright
 * Copyright (C) 2013, Takazumi Shirayanagi\n
 * The new BSD License is applied to this software.
 * see LICENSE
*/
/*----------------------------------------------------------------------
======================================================================*/
#ifndef INCG_IRIS_iutest_params_util_C_H_4B4332BA_2300_416B_A1EE_004BC08A627E_
#define INCG_IRIS_iutest_params_util_C_H_4B4332BA_2300_416B_A1EE_004BC08A627E_

/* include ===========================================================*/
#include "../iutest_defs_c.h"

#if IUTEST_C_HAS_PARAM_TEST

/* define ============================================================*/
/** @private */
#define iuTestParamHolder_ctor(testcase_name_, testcases_, params)	{	\
	NULL, IUTEST_PP_TOSTRING(testcase_name_), testcases_, params		\
	, sizeof(params[0]), sizeof(params)/sizeof(params[0]), NULL }

/* struct ============================================================*/
/**
 * @brief	ParameterHolder
*/
typedef struct iuTestParamHolder_t
{
	const char**	testcase_names;		/*!< eXgP[X */
	const char*		testcase_base_name;	/*!< eXgP[X */
	iuTestCase*		testcases;			/*!< o^peXgP[Xz */
	void*			params;				/*!< p[^z */
	size_t			align;				/*!< p[^ACg */
	size_t			elem;				/*!< p[^ */
	struct iuTestParamHolder_t	*next;	/*!<  iuTestParamHolder ̃m[h */
} iuTestParamHolder;

#endif	/* IUTEST_C_HAS_PARAM_TEST */

#endif

==> iutest_c-1.3.0.zip: iutest_c-1.3.0/include/internal/iutest_params_util_c.h <==
/*======================================================================
----------------------------------------------------------------------*/
/**
 * @file		iutest_params_util_c.h
 * @brief		iris unit test parameter eXgp util t@C
 *
 * @author		t.sirayanagi
 * @version		1.0
 *
 * @par			copyright
 * Copyright (C) 2013, Takazumi Shirayanagi\n
 * The new BSD License is applied to this software.
 * see LICENSE
*/
/*----------------------------------------------------------------------
======================================================================*/
#ifndef INCG_IRIS_iutest_params_util_C_H_4B4332BA_2300_416B_A1EE_004BC08A627E_
#define INCG_IRIS_iutest_params_util_C_H_4B4332BA_2300_416B_A1EE_004BC08A627E_

/* include ===========================================================*/
#include "../iutest_defs_c.h"

#if IUTEST_C_HAS_PARAM_TEST

/* define ============================================================*/
/** @private */
#define iuTestParamHolder_ctor(testcase_name_, testcases_, params)	{	\
	NULL, IUTEST_PP_TOSTRING(testcase_name_), testcases_, params		\
	, sizeof(params[0]), IUTEST_PP_COUNTOF(params), NULL }

/* struct ============================================================*/
/**
 * @brief	ParameterHolder
*/
typedef struct iuTestParamHolder_t
{
	const char**	testcase_names;		/*!< eXgP[X */
	const char*		testcase_base_name;	/*!< eXgP[X */
	iuTestCase*		testcases;			/*!< o^peXgP[Xz */
	void*			params;				/*!< p[^z */
	size_t			align;				/*!< p[^ACg */
	size_t			elem;				/*!< p[^ */
	struct iuTestParamHolder_t	*next;	/*!<  iuTestParamHolder ̃m[h */
} iuTestParamHolder;

#endif	/* IUTEST_C_HAS_PARAM_TEST */

#endif
